@@ -377,11 +377,11 @@ def profile_genome(t, window_ogs, ogtable, center):
 
     return g
 
-if __name__ == '__main__':
+def main():
+    
+    # import cProfile, pstats
 
-    import cProfile, pstats
-
-    runprofile = cProfile.Profile()
+    #runprofile = cProfile.Profile()
 
     args = parse_args()
 
@@ -490,11 +490,11 @@ if __name__ == '__main__':
 
         g = profile_genome(t, window_ogs, ogtable, center)
 
-        runprofile.enable()
+        #runprofile.enable()
         res = g.__repr__(label_map=label_map)
         #res = fg.WHITE + bg.BLACK + "IHateThis" + Style.RESET_ALL
-        runprofile.disable()
-        stats = pstats.Stats(runprofile).sort_stats('cumtime')
+        #runprofile.disable()
+        #stats = pstats.Stats(runprofile).sort_stats('cumtime')
         #stats.print_stats(10)
         
         if res:
@@ -506,3 +506,6 @@ if __name__ == '__main__':
     htmloutputfilepath = pathlib.Path(args.outdir) / 'vicinator.out.html'
     with open(htmloutputfilepath, 'w') as htmlout:
         htmlout.write(converter.convert(full_output))
+
+if __name__ == '__main__':
+    main()
